@@ -16,6 +16,7 @@ from struct import (
     unpack as struct_unpack
 )
 from io import BytesIO
+from os import PathLike
 from pathlib import Path
 from functools import partial
 from dataclasses import dataclass
@@ -34,7 +35,7 @@ from .errors import (
 )
 from . import loop
 from .keys import FileKey, MainKey
-from .crypto import AESwState, aes_encrypt
+from .crypto import AESwState as AES
 
 
 __all__ = [
@@ -186,24 +187,19 @@ class RemoteBoxFileMetadata:
           + self.comment + int_to_bytes(len(self.file_name),2,signed=False) \
           + self.file_name.encode()
         )
-        filedata = next(aes_encrypt(
-            filedata, self.filekey, yield_all=True
-        ))
+        filedata = AES(self.filekey).encrypt(filedata)
         assert len(filedata) <= FILEDATA_MAX
 
         if self.preview:
-            preview = next(aes_encrypt(
-                self.preview, self.filekey, yield_all=True
-            ))
+            preview = AES(self.filekey).encrypt(preview)
             assert len(preview) <= PREVIEW_MAX+16 
         else:
             preview = b''
 
         navbytes = int_to_bytes(len(filedata),3,signed=False) \
             + int_to_bytes(len(preview),3,signed=False)
-        navbytes = next(aes_encrypt(
-            navbytes, self.filekey, yield_all=True
-        ))
+
+        navbytes = AES(self.filekey).encrypt(navbytes)
         assert len(navbytes) == NAVBYTES_SIZE
 
         metadata += navbytes + filedata + preview
@@ -320,12 +316,13 @@ class SearchFilter:
             verbyte = self.verbyte + other.verbyte,
             exported = other.exported, re = self.re
         )
-class OpenPretender: 
-    def __init__(self, flo: BinaryIO, aes_state: AESwState, mode: int):
+class OpenPretender:
+    """
+    Class to wrap Tgbox AES Generators and make it look
+    like opened to "rb"-read file. Designed to work with Telethon.
+    """
+    def __init__(self, flo: BinaryIO, aes_state: AES, mode: int):
         """
-        Class to wrap Tgbox AES Generators and make it look
-        like opened to "rb"-read file. Designed to work with Telethon.
-        
         Arguments:
             flo (``BinaryIO``):
                 File-like object. Like ``open('file','rb')``.
@@ -509,16 +506,16 @@ async def get_media_duration(file_path: str) -> float:
         raise DurationImpossible('Can\'t get media duration') from None 
 
 async def make_media_preview(
-        file_path: str, 
-        output_path: str='', 
-        x: int=128, 
-        y: int=-1) -> BinaryIO:
+        file_path: PathLike, 
+        temp_path: Optional[PathLike] = None,
+        x: int=128, y: int=-1) -> BinaryIO:
     """
     Makes x:y sized thumbnail of the 
     video/audio with ffmpeg. "-1"
     preserves one of side size.
     """
-    thumbnail_path = Path(output_path, prbg(8).hex()+'.jpg')
+    temp_path = Path() if not temp_path else temp_path
+    thumbnail_path = Path(temp_path, prbg(4).hex()+'.jpg')
     
     func = partial(subprocess_run,
         args=[
